@@ -1,12 +1,13 @@
 import json
 import os
+import re
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
 from devsecops_engine_tools.engine_utilities import settings
 
 logger = MyLogger.__call__(**settings.SETTING_LOGGER).get_logger()
 
 
-def generate_file_from_tool(tool, result_list, rules_doc, default_severity, default_category):
+def generate_file_from_tool(tool, result_list, rules_doc, config_tool):
     if tool == "CHECKOV":
         try:
             if len(result_list) > 0:
@@ -20,7 +21,7 @@ def generate_file_from_tool(tool, result_list, rules_doc, default_severity, defa
                 for result in result_list:
                     failed_checks = result.get("results", {}).get("failed_checks", [])
                     all_failed_checks.extend(
-                        map(lambda x: update_fields(x, rules_doc, default_severity, default_category), failed_checks)
+                        map(lambda x: update_fields(x, rules_doc, config_tool), failed_checks)
                     )
                     summary_passed += result.get("summary", {}).get("passed", 0)
                     summary_failed += result.get("summary", {}).get("failed", 0)
@@ -60,14 +61,18 @@ def generate_file_from_tool(tool, result_list, rules_doc, default_severity, defa
             logger.error(f"Error during handling checkov json integrator {ex}")
 
 
-def update_fields(check_result, rules_doc, default_severity, default_category):
+def update_fields(check_result, rules_doc, config_tool):
     rule_info = rules_doc.get(check_result.get("check_id"), {})
 
-    check_result["severity"] = rule_info.get("severity", default_severity)
-    check_result["bc_category"] = rule_info.get("category", default_category)
+    check_result["severity"] = rule_info.get("severity", config_tool.get("DEFAULT_SEVERITY"))
+    check_result["bc_category"] = rule_info.get("category", config_tool.get("DEFAULT_CATEGORY"))
     if "customID" in rule_info:
         check_result["custom_vuln_id"] = rule_info["customID"]
     if "guideline" in rule_info:
         check_result["guideline"] = rule_info["guideline"]
 
+    regex_clean = config_tool.get("REGEX_CLEAN_RESOURCE")
+    if regex_clean:
+        check_result["resource"] = re.sub(regex_clean, "", check_result.get("resource", ""))
+
     return check_result
